@@ -67,6 +67,7 @@
 ##!         args.ar1c = list(Z = NULL, Q.beta = NULL),
 ##!         args.intslope = list(subject = NULL, strata = NULL, covariates = NULL), 
 ##!         correct = NULL,
+##!         vb.correct = NULL,
 ##!         locations = NULL, 
 ##!         debug = FALSE)
 ##!}
@@ -330,6 +331,9 @@
     ##!\item{correct}{Add this model component to the list of variables to be used in the corrected Laplace approximation? If \code{NULL} use default choice,  otherwise correct if \code{TRUE} and do not if \code{FALSE}. (This option is currently experimental.)},
     correct = NULL,
 
+    ##!\item{vb.correct}{Add this model component to the list of variables to be used for the vb corrected Laplace approximation? If \code{NULL} use default choice,  otherwise correct if \code{TRUE} and do not if \code{FALSE}. (expert option)},
+    vb.correct = NULL,
+
     ##!\item{locations}{A matrix with locations for the model \code{dmatern}. This also defines \code{n}.}
     locations = NULL,
     
@@ -872,13 +876,9 @@
         }
     }
 
-    ##for all instrinsic model the constraint has to be ON...
-    ##...except if the rw is cyclic!!!!!
+    ## for all instrinsic model the constraint has to be default ON
     if (is.null(constr)) {
         constr = inla.model.properties(model, "latent")$constr
-        if (!is.null(cyclic) && cyclic) {
-            constr=FALSE
-        }
     }
 
     ## if diagonal is not set, the set this depending on the constr
@@ -891,7 +891,7 @@
     }
 
     if (!empty.extraconstr(extraconstr)) {
-        ##check
+        ## check
         A=extraconstr$A
         e=extraconstr$e
         if (!is.matrix(A)) {
@@ -903,7 +903,9 @@
         }
     }
 
-    if (!missing(scale.model) && !inla.one.of(model, c("rw1", "rw2", "besag", "bym", "bym2", "besag2", "rw2d", "rw2diid", "seasonal"))) {
+    if (!missing(scale.model) && !inla.one.of(model, c("rw1", "rw2", "besag", "bym",
+                                                       "bym2", "besag2", "rw2d",
+                                                       "rw2diid", "seasonal"))) {
         stop(paste("Option 'scale.model' is not used for model:", model))
     }
     if (missing(scale.model) || is.null(scale.model)) {
@@ -935,7 +937,7 @@
                 rankdef = rankdef + dim(extraconstr$A)[1]
             }
         }
-            
+        
         if (adjust.for.con.comp) {
             ## we need to check if the graph contains more than 1 connected components. 
             if (g$cc$n == 1) {
@@ -1065,6 +1067,7 @@
         args.slm = args.slm,
         args.ar1c = args.ar1c,
         correct = correct,
+        vb.correct = vb.correct,
         locations = locations
         )
 
