@@ -906,6 +906,7 @@
     }
     inla.write.boolean.field("control.vb.enable", inla.spec$control.vb$enable, file)
     inla.write.boolean.field("control.vb.verbose", inla.spec$control.vb$verbose, file)
+    inla.write.boolean.field("control.vb.hyperpar.correct", inla.spec$control.vb$hyperpar.correct, file)
     cat("control.vb.strategy = ", inla.spec$control.vb$strategy, "\n", file = file, append = TRUE)
     cat("control.vb.refinement = ", inla.spec$control.vb$refinement, "\n", file = file, append = TRUE)
     cat("control.vb.max.correct = ", inla.spec$control.vb$max.correct, "\n", file = file, append = TRUE)
@@ -1004,6 +1005,8 @@
         cat("AextPrecision = ", predictor.spec$precision, "\n", append=TRUE, sep = " ", file = file)
     }
 
+    inla.write.boolean.field("vb.correct", predictor.spec$vb.correct, file)
+
     cat("\n", sep = " ", file = file,  append = TRUE)
 }
 
@@ -1011,7 +1014,7 @@
         cpo, po, mlik, quantiles, smtp, q, openmp.strategy, graph, config, gdensity)
 {
     cat("", sep = "", file = file, append=FALSE)
-    cat("###  ", inla.version("hgid"), "\n", sep = "", file = file,  append = TRUE)
+    cat("###  ", inla.version("version"), "\n", sep = "", file = file,  append = TRUE)
     cat("###  ", inla.paste(Sys.info()), "\n", sep = "", file = file,  append = TRUE)
     cat("###  ", inla.os.type(), "-", inla.os.32or64bit(), "bit", " ", date(), "\n", sep = "", file = file,  append = TRUE)
 
@@ -1037,7 +1040,8 @@
     cat(inla.secsep("INLA.Model"), "\n", sep = " ", file = file,  append = TRUE)
     cat("type = problem\n", sep = " ", file = file,  append = TRUE)
     cat("dir = $inlaresdir\n", sep = " ", file = file,  append = TRUE)
-    cat("rinla.tag = ", inla.version("hgid"), "\n", file = file,  append = TRUE)
+    cat("rinla.version = ", inla.version("version"), "\n", file = file,  append = TRUE)
+    cat("rinla.bdate = ", inla.version("date"), "\n", file = file,  append = TRUE)
     inla.write.boolean.field("return.marginals", return.marginals, file)
     inla.write.boolean.field("hyperparameters", hyperpar, file)
     inla.write.boolean.field("cpo", cpo, file)
